==> wifieye_0.6.1.orig.tar.gz: wifieye-0.6.1/src/win_channels.py <==
#!/usr/bin/env python
# coding=UTF-8
#
# Copyright (C) 2010 Stefanos Harhalakis
#
# This file is part of wifieye.
#
# wifieye is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# wifieye is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with wifieye.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: win_channels.py 2591 2010-05-25 14:49:10Z v13 $

__version__ = "$Id: win_channels.py 2591 2010-05-25 14:49:10Z v13 $"

from PyQt4 import QtGui, QtCore
from PyQt4.QtCore import SIGNAL, Qt
from PyQt4.QtGui import *

import sys

import graphchannels

from win_common import Ui_Common

class Ui_Channels(Ui_Common):
    def __init__(self):
	Ui_Common.__init__(self, 'channels')

    def setupUi(self, w):
	self.centralwidget=QtGui.QWidget(w)
	self.centralwidget.setObjectName("centralwidget")

	self.l0=QtGui.QVBoxLayout(self.centralwidget)

	self.graph=graphchannels.GraphChannels()
	self.graph.setObjectName("graph")
	self.l0.addWidget(self.graph)

	# The buttons
	self.l1=QtGui.QHBoxLayout()

	# Common buttons first
	cmn=self.getCommonButtons()
	for i in cmn:
	    self.l1.addWidget(i)

	self.buttonRefresh=QtGui.QPushButton()
	self.l1.addWidget(self.buttonRefresh)

	self.buttonAutoRefresh=QtGui.QPushButton()
	self.buttonAutoRefresh.setCheckable(True)
	self.l1.addWidget(self.buttonAutoRefresh)

	spacer=QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
	    QtGui.QSizePolicy.Minimum)
	self.l1.addItem(spacer)
	self.l0.addLayout(self.l1)

	self.w=self.centralwidget

    def retranslateUi(self):
	self.buttonRefresh.setText("Refresh")
	self.buttonAutoRefresh.setText("Auto Refresh")

# vim: set ts=8 sts=4 sw=4 noet formatoptions=r ai nocindent:

==> wifieye_1.0.orig.tar.gz: wifieye-1.0/src/win_channels.py <==
#!/usr/bin/env python
# coding=UTF-8
#
# Copyright (C) 2010 Stefanos Harhalakis
#
# This file is part of wifieye.
#
# wifieye is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# wifieye is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with wifieye.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: win_channels.py 2599 2010-06-02 17:24:26Z v13 $

__version__ = "$Id: win_channels.py 2599 2010-06-02 17:24:26Z v13 $"

from PyQt4 import QtGui, QtCore
from PyQt4.QtCore import SIGNAL, Qt
from PyQt4.QtGui import *

import sys

import graphchannels

from win_common import Ui_Common

class Ui_Channels(Ui_Common):
    def __init__(self, parent):
	Ui_Common.__init__(self, parent, 'channels')

    def setupUi(self, w):
	self.centralwidget=QtGui.QWidget(w)
	self.centralwidget.setObjectName("centralwidget")

	self.l0=QtGui.QVBoxLayout(self.centralwidget)

	self.graph=graphchannels.GraphChannels()
	self.graph.setObjectName("graph")
	self.l0.addWidget(self.graph)

	# The buttons
	self.l1=QtGui.QHBoxLayout()

	# Common buttons first
	cmn=self.getCommonButtons()
	for i in cmn:
	    self.l1.addWidget(i)

	self.buttonRefresh=QtGui.QPushButton()
	self.l1.addWidget(self.buttonRefresh)

	self.buttonAutoRefresh=QtGui.QPushButton()
	self.buttonAutoRefresh.setCheckable(True)
	self.l1.addWidget(self.buttonAutoRefresh)

	spacer=QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
	    QtGui.QSizePolicy.Minimum)
	self.l1.addItem(spacer)
	self.l0.addLayout(self.l1)

	self.w=self.centralwidget

    def retranslateUi(self):
	self.buttonRefresh.setText("Refresh")
	self.buttonAutoRefresh.setText("Auto Refresh")

# vim: set ts=8 sts=4 sw=4 noet formatoptions=r ai nocindent:
